@@ -18,5 +18,8 @@ NULL
 
 
 
-#' @importFrom wrapr %.>% :=
+#' @importFrom wrapr %.>% := mk_tmp_name_source wrapr_function pipe_step
+NULL
+
+#' @importFrom DBI dbGetQuery
 NULL
