@@ -134,6 +134,7 @@ columns_used.relop_rename_columns <- function (x, ...,
 to_sql.relop_rename_columns <- function (x,
                                          db,
                                          ...,
+                                         limit = NULL,
                                          source_limit = NULL,
                                          indent_level = 0,
                                          tnum = mk_tmp_name_source('tsql'),
@@ -154,6 +155,7 @@ to_sql.relop_rename_columns <- function (x,
   cols <- paste(colsV, "AS", colsA)
   subsql_list <- to_sql(x$source[[1]],
                         db = db,
+                        limit = limit,
                         source_limit = source_limit,
                         indent_level = indent_level + 1,
                         tnum = tnum,
@@ -168,6 +170,10 @@ to_sql.relop_rename_columns <- function (x,
               subsql, "\n",
               prefix, ") ",
               tab)
+  if(!is.null(limit)) {
+    q <- paste(q, "LIMIT",
+               format(ceiling(limit), scientific = FALSE))
+  }
   if(append_cr) {
     q <- paste0(q, "\n")
   }
