@@ -163,6 +163,7 @@ columns_used.relop_select_rows <- function (x, ...,
 to_sql.relop_select_rows <- function (x,
                                       db,
                                       ...,
+                                      limit = NULL,
                                       source_limit = NULL,
                                       indent_level = 0,
                                       tnum = mk_tmp_name_source('tsql'),
@@ -194,6 +195,10 @@ to_sql.relop_select_rows <- function (x,
          tab, "\n",
          prefix, "WHERE ",
          re_expr)
+  if(!is.null(limit)) {
+    q <- paste(q, "LIMIT",
+               format(ceiling(limit), scientific = FALSE))
+  }
   if(append_cr) {
     q <- paste0(q, "\n")
   }
